@@ -46,6 +46,10 @@ Arguably, they should be declared in qal.dal.types instead.
 
 
 def mysql_type_to_SQL_type(_type_code):
+    """
+    Convert the internal MySQL type to the SQL type
+    :param _type_code: A MySQL field constant
+    """
     if _type_code in (
         MySQL_VARCHAR, 
         MySQL_VAR_STRING,
@@ -87,7 +91,10 @@ def mysql_type_to_SQL_type(_type_code):
         raise Exception("mysql_type_to_SQL_type: _type_code \"" + str(_type_code) + "\"not supported") 
     
 def python_type_to_SQL_type(_python_type):
-
+    """
+    Convert a python data type to ab SQL type.
+    :param _python_type: A Python internal type
+    """
     if (_python_type == str):
         return 'string'
     elif (_python_type == bytes):
@@ -97,7 +104,7 @@ def python_type_to_SQL_type(_python_type):
     elif (_python_type == int):
         return "integer"    
     elif (_python_type == datetime):
-        return "timestamp"
+        return "datetime"
     elif (_python_type == bool):
         return "boolean"
     else:
@@ -105,6 +112,10 @@ def python_type_to_SQL_type(_python_type):
     
         
 def parse_description(_descriptions, _db_type):
+    """Convert field descriptions to field name- and field type-lists.
+    :param _descriptions: A list of descriptions
+    :param _db_type: The database type
+    """
     _field_names = []
     _field_types = []
     
